pub enum PeerTarget {
Local(MeerkatId),
External(TrustedPeerSpec),
}Expand description
Target for a wire operation from a local mob member.
Variants
Local(MeerkatId)
Another member in the same mob roster.
External(TrustedPeerSpec)
A trusted peer that lives outside the local mob roster.