StepCompletionOpts

Struct StepCompletionOpts 

pub struct StepCompletionOpts<'a> {
    pub node_id: &'a FlowNodeId,
    pub step_id: &'a StepId,
    pub output: Value,
    pub loop_context: Option<(&'a LoopId, u64)>,
    pub max_retries: usize,
}
Options for completing a step node and recording its output.

Fields

node_id: &'a FlowNodeId

The frame node that was admitted as a step.

step_id: &'a StepId

The step ID used to store the output.

output: Value

The output value produced by the step executor.

loop_context: Option<(&'a LoopId, u64)>

None for root frame steps (stored in root_step_outputs). Some((loop_id, iteration)) for loop body steps (stored in loop_iteration_outputs[loop_id][iteration]).

max_retries: usize

Maximum number of CAS retries before returning an error.