#[non_exhaustive]pub struct PreviousMemberCleanupReport {
pub identity: AgentIdentity,
pub retire_attempted: bool,
pub retire_error: Option<String>,
pub confirmatory_observation_attempted: bool,
pub confirmatory_observation: Option<String>,
pub destroy_attempted: bool,
pub destroy_error: Option<String>,
/* private fields */
}Expand description
Structured evidence captured when respawn cannot prove the old member is gone.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.identity: AgentIdentityStable member identity.
retire_attempted: boolWhether graceful retire was attempted.
retire_error: Option<String>Error returned from the graceful retire attempt, when any.
confirmatory_observation_attempted: boolWhether a confirmatory observation probe was attempted.
confirmatory_observation: Option<String>Observation probe detail, when any.
destroy_attempted: boolWhether force-destroy was attempted.
destroy_error: Option<String>Error returned from the force-destroy attempt, when any.